@@ -6,17 +6,16 @@ import girok.utils.display as display_utils
 cfg = get_config()
 
 base_url = cfg.base_url 
-email_base_url = cfg.email_base_url
 
 def register(email, password):
-    resp = requests.post(email_base_url + "/register", json={
+    resp = requests.post(base_url + "/register", json={
         "email": email,
         "password": password
     })
     return resp
 
 def verify_verification_code(email, verification_code):
-    resp = requests.post(email_base_url + "/register/verification_code", json={
+    resp = requests.post(base_url + "/register/verification_code", json={
         "email": email,
         "verification_code": verification_code
     })
@@ -24,13 +23,13 @@ def verify_verification_code(email, verification_code):
         return True
     elif resp.status_code == 401:
         err_msg = general_utils.bytes2dict(resp.content)['detail']
-        display_utils.center_print(err_msg, type="error")
-        exit(0)
+        # display_utils.center_print(err_msg, type="error")
+        return False
     else:
         err_msg = general_utils.bytes2dict(resp.content)['detail'][0]['msg']
-        print(err_msg)
-        display_utils.center_print(str(err_msg), type="error") 
-        exit(0)
+        # print(err_msg)
+        # display_utils.center_print(str(err_msg), type="error") 
+        return False
     
 
 def login(email, password):
